% Copyright (C) 2016  Peer Neubert, peer.neubert@etit.tu-chemnitz.de
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% -------------------------------------
% 
% shift = findBestHorizontalInitializationShift(G, nBorders)
% 
% Find horizontal shift with best overlap to hiegh gradients for a regular
% grid.
% 
% G ... weights, e.g. gradient image
% nBorders ... number of splits of the image
%
function shift = findBestHorizontalInitializationShift(G, nBorders)

  [h,w,c] = size(G);
  step = w/(nBorders+1);
  
  % column sums
  sg = sum(G);
  
  % smoothing (optional)    
  sigma = 0.05*step;
  gaus = fspecial('gaussian',[1 round(step/2)], sigma);
  sg = imfilter(sg, gaus, 'same');
  
  % erase first and last half step
  sg(1:round(step/2)-1) = 0;
  sg(end-round(step/2):end) = 0;
  
  % find best shift  
  startIdx = round(step/2 + [0:(nBorders-1)]*step);
  endIdx = startIdx + round(step);
  
  S=zeros(nBorders,round(step)+1);
  for i=1:nBorders
    S(i,:) = sg(startIdx(i):endIdx(i));
  end
  
  SS = sum(S);
  
  [~, idx] = max(SS);
  
  shift = round(idx-1-step/2);
  
  
end